@@ -1,5 +1,5 @@
 package DBICx::Shortcuts;
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 
 use strict;
 use warnings;
@@ -14,8 +14,8 @@ sub setup {
   die if $@;
   local $ENV{DBIC_NO_VERSION_CHECK} = 1;
   my $schema = $schema_class->connect;
-  
-  SOURCE: for my $source ($schema->sources) {
+
+SOURCE: for my $source ($schema->sources) {
     my $info = $schema->source($source)->source_info;
     next SOURCE if exists $info->{skip_shortcut} && $info->{skip_shortcut};
 
@@ -26,42 +26,52 @@ sub setup {
     }
     else {
       $method = $source;
-      $method =~ s/.+::(.+)$/$1/; ## deal with nested sources
+      $method =~ s/.+::(.+)$/$1/;              ## deal with nested sources
       $method =~ s/([a-z])([A-Z])/${1}_$2/g;
       $method = lc($method);
     }
-    
+
     croak("Shortcut failed, '$method' already defined in '$class', ")
       if $class->can($method);
-    
+
     no strict 'refs';
-    *{__PACKAGE__."::$method"} = sub {
+    *{__PACKAGE__ . "::$method"} = sub {
       my $rs = shift->schema->resultset($source);
-      
+
+      ## No arguments, return empty result set;
       return $rs unless @_;
+
+      ## first argument not a reference, assume find by PK
       return $rs->find(@_) if defined($_[0]) && !ref($_[0]);
+
+      ## first argument is a scalar ref, assume unique constraint name,
+      ## use find
+      return $rs->find(@_[1 .. $#_], {key => ${$_[0]}})
+        if defined($_[0]) && ref($_[0]) eq 'SCALAR';
+
+      ## otherwise, its a search
       return $rs->search(@_);
     };
   }
-  
+
   ## Enable set of schema shortcuts
   for my $meth (@methods) {
     no strict 'refs';
     *{__PACKAGE__ . "::$meth"} = sub { return shift->schema->$meth(@_) };
   }
 
-  $schemas{$class} = { class => $schema_class };
-  
+  $schemas{$class} = {class => $schema_class};
+
   return;
 }
 
 sub schema {
   my ($class) = @_;
-  
+
   croak("Class '$class' did not call 'setup()'")
     unless exists $schemas{$class};
 
-  my $info = $schemas{$class};
+  my $info   = $schemas{$class};
   my $schema = $info->{schema};
   return $schema if $schema;
 
@@ -86,7 +96,7 @@ DBICx::Shortcuts - Setup a class with shortcut methods to the sources of a DBIx:
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -112,7 +122,10 @@ version 0.006
   $book = S->books->create({ ... });
   
   # With first argument as a defined non-ref, passes @_ to find()
-  $book = S->books(42);  ## 42 is the ID of the book
+  $book = S->books(42);  ## 42 is the PK of the book
+  
+  # With first argument as a ScalarRef, uses a unique constraint
+  $book = S->book(\'isbn_key', '9123123432123');
   
   # All other cases, calls search()
   $rs = S->books({title => { like => '%Perl%' }});
@@ -134,7 +147,7 @@ the real Schema class using the L<"setup()"> method.
 For each source defined in your schema class, a method will be created
 in the shortcut class.
 
-This method can be used in three ways.
+This method can be used in four ways.
 
 If called without parameters, the shortcut method will return a
 ResultSet for the source. Usefull to call create().
@@ -142,6 +155,10 @@ ResultSet for the source. Usefull to call create().
 If called with parameters where the first is not a reference, it calls
 find(). Usefull to fetch a row based on the primary key.
 
+If called with parameters where the first is a scalarRef, we assume it
+to be the name of the unique constraint to use, and the rest of the
+arguments to be the required values for that constraint.
+
 In all other cases, it calls search() and returns the resultset.
 
 
